@@ -18,6 +18,7 @@
 from django.utils.translation import ugettext_lazy as _
 
 from plinth import cfg
+from plinth.modules.backups.api import validate as validate_backup
 from plinth.clients import validate
 from plinth.utils import format_lazy
 
@@ -46,21 +47,15 @@ clients = validate([{
     }]
 }])
 
-backup = {
-    'config': {
-        'directories': [],
-        'files': [],
-    },
+backup = validate_backup({
     'data': {
-        'directories': ['/var/lib/infinoted/'],
-        'files': [],
+        'directories': ['/var/lib/infinoted/']
     },
     'secrets': {
-        'directories': [],
         'files': [
             '/etc/infinoted/infinoted-cert.pem',
             '/etc/infinoted/infinoted-key.pem'
         ],
     },
     'services': ['infinoted']
-}
+})
