@@ -18,13 +18,14 @@
 from django.utils.translation import ugettext_lazy as _
 
 from plinth.clients import store_url, validate
+from plinth.modules.backups.api import validate as validate_backup
 
 clients = validate([{
     'name':
-        _('DAVDroid'),
+        _('DAVx5'),
     'usage':
         _('Enter the URL of the Radicale server (e.g. '
-          'http://localhost:5232) and your user name. DAVdroid will '
+          'https://<your.freedombox.address>) and your user name. DAVx5 will '
           'show all existing calendars and address books and you can '
           'create new.'),
     'platforms': [{
@@ -76,7 +77,7 @@ clients = validate([{
     'usage':
         _('In Evolution add a new calendar and address book '
           'respectively with WebDAV. Enter the URL of the Radicale '
-          'server (e.g. http://localhost:5232) and your user name. '
+          'server (e.g. https://<your.freedombox.address>) and your user name. '
           'Clicking on the search button will list the existing '
           'calendars and address books.'),
     'platforms': [{
@@ -86,18 +87,9 @@ clients = validate([{
     }]
 }])
 
-backup = {
-    'config': {
-        'directories': [],
-        'files': [],
-    },
+backup = validate_backup({
     'data': {
-        'directories': ['/var/lib/radicale/'],
-        'files': [],
-    },
-    'secrets': {
-        'directories': [],
-        'files': [],
+        'directories': ['/var/lib/radicale/']
     },
     'services': ['radicale']
-}
+})
