@@ -26,7 +26,7 @@ from plinth import action_utils, actions, frontpage
 from plinth.menu import main_menu
 from plinth.views import ServiceView
 
-from .manifest import clients
+from .manifest import backup, clients
 
 version = 2
 
@@ -69,7 +69,7 @@ manual_page = 'Repro'
 def init():
     """Initialize the repro module."""
     menu = main_menu.get('apps')
-    menu.add_urlname(name, 'glyphicon-phone-alt', 'repro:index',
+    menu.add_urlname(name, 'repro', 'repro:index',
                      short_description)
 
     global service
