@@ -23,7 +23,9 @@ from django.utils.translation import ugettext_lazy as _
 from plinth import actions
 from plinth.menu import main_menu
 
-version = 4
+from .manifest import backup
+
+version = 5
 
 is_essential = True
 
@@ -44,14 +46,13 @@ ACCESS_CONF_SNIPPETS = [OLD_ACCESS_CONF_SNIPPET, ACCESS_CONF_SNIPPET]
 def init():
     """Initialize the module"""
     menu = main_menu.get('system')
-    menu.add_urlname(name, 'glyphicon-lock', 'security:index')
+    menu.add_urlname(name, 'fa-lock', 'security:index')
 
 
 def setup(helper, old_version=None):
     """Install the required packages"""
     helper.install(managed_packages)
-    if not old_version:
-        setup_fail2ban()
+    setup_fail2ban()
 
     if get_restricted_access_enabled():
         set_restricted_access(True)
@@ -60,6 +61,7 @@ def setup(helper, old_version=None):
 def setup_fail2ban():
     actions.superuser_run('service', ['unmask', 'fail2ban'])
     actions.superuser_run('service', ['enable', 'fail2ban'])
+    actions.superuser_run('service', ['reload', 'fail2ban'])
 
 
 def get_restricted_access_enabled():
