@@ -30,6 +30,7 @@ from django.utils.translation import ugettext_lazy
 from plinth import actions
 from plinth.errors import ActionError
 from plinth.modules import snapshot as snapshot_module
+from plinth.modules import storage
 
 from . import get_configuration
 from .forms import SnapshotForm
@@ -43,8 +44,24 @@ subsubmenu = [{
 }]
 
 
+def not_supported_view(request):
+    """Show that snapshots are not supported on the system."""
+    template_data = {
+        'title': snapshot_module.name,
+        'description': snapshot_module.description,
+        'fs_type': storage.get_filesystem_type(),
+        'fs_types_supported': snapshot_module.fs_types_supported,
+        'manual_page': snapshot_module.manual_page,
+    }
+    return TemplateResponse(request, 'snapshot_not_supported.html',
+                            template_data)
+
+
 def index(request):
     """Show snapshot list."""
+    if not snapshot_module.is_supported():
+        return not_supported_view(request)
+
     status = get_configuration()
     if request.method == 'POST':
         form = SnapshotForm(request.POST)
@@ -66,21 +83,33 @@ def index(request):
 
 def manage(request):
     """Show snapshot list."""
+    if not snapshot_module.is_supported():
+        return not_supported_view(request)
+
     if request.method == 'POST':
         if 'create' in request.POST:
             actions.superuser_run('snapshot', ['create'])
             messages.success(request, _('Created snapshot.'))
+        if 'delete_selected' in request.POST:
+            if request.POST.getlist('snapshot_list'):
+                snapshot_to_delete = request.POST.getlist('snapshot_list')
+                request.session['snapshots'] = snapshot_to_delete
+                return redirect(reverse('snapshot:delete-selected'))
 
     output = actions.superuser_run('snapshot', ['list'])
     snapshots = json.loads(output)
     has_deletable_snapshots = any(
         [snapshot for snapshot in snapshots[1:] if not snapshot['is_default']])
 
-    return TemplateResponse(request, 'snapshot_manage.html', {
-        'snapshots': snapshots,
-        'has_deletable_snapshots': has_deletable_snapshots,
-        'subsubmenu': subsubmenu,
-    })
+    return TemplateResponse(
+        request, 'snapshot_manage.html', {
+            'title': snapshot_module.name,
+            'description': snapshot_module.description,
+            'manual_page': snapshot_module.manual_page,
+            'snapshots': snapshots,
+            'has_deletable_snapshots': has_deletable_snapshots,
+            'subsubmenu': subsubmenu,
+        })
 
 
 def update_configuration(request, old_status, new_status):
@@ -89,25 +118,26 @@ def update_configuration(request, old_status, new_status):
     def make_config(args):
         key, stamp = args[0], args[1]
         if old_status[key] != new_status[key]:
+            if 'limit' in key:
+                return stamp.format('0-{}'.format(new_status[key]))
+
             return stamp.format(new_status[key])
-        else:
-            return None
 
-    new_status['number_min_age'] = int(new_status['number_min_age']) * 86400
+        return None
 
-    config = filter(None,
-                    map(make_config, [
-                        ('enable_timeline_snapshots', 'TIMELINE_CREATE={}'),
-                        ('hourly_limit', 'TIMELINE_LIMIT_HOURLY={}'),
-                        ('daily_limit', 'TIMELINE_LIMIT_DAILY={}'),
-                        ('weekly_limit', 'TIMELINE_LIMIT_WEEKLY={}'),
-                        ('monthly_limit', 'TIMELINE_LIMIT_MONTHLY={}'),
-                        ('yearly_limit', 'TIMELINE_LIMIT_YEARLY={}'),
-                        ('number_min_age', 'NUMBER_MIN_AGE={}'),
-                    ]))
+    config = filter(
+        None,
+        map(make_config, [
+            ('enable_timeline_snapshots', 'TIMELINE_CREATE={}'),
+            ('hourly_limit', 'TIMELINE_LIMIT_HOURLY={}'),
+            ('daily_limit', 'TIMELINE_LIMIT_DAILY={}'),
+            ('weekly_limit', 'TIMELINE_LIMIT_WEEKLY={}'),
+            ('monthly_limit', 'TIMELINE_LIMIT_MONTHLY={}'),
+            ('yearly_limit', 'TIMELINE_LIMIT_YEARLY={}'),
+            ('free_space', 'FREE_LIMIT={}'),
+        ]))
 
-    if old_status['enable_software_snapshots'] != new_status[
-            'enable_software_snapshots']:
+    if old_status['enable_software_snapshots'] != new_status['enable_software_snapshots']:
         if new_status['enable_software_snapshots'] == 'yes':
             actions.superuser_run('snapshot', ['disable-apt-snapshot', 'no'])
         else:
@@ -118,44 +148,46 @@ def update_configuration(request, old_status, new_status):
 
         messages.success(request, _('Storage snapshots configuration updated'))
     except ActionError as exception:
-        messages.error(request,
-                       _('Action error: {0} [{1}] [{2}]').format(
-                           exception.args[0], exception.args[1],
-                           exception.args[2]))
+        messages.error(
+            request,
+            _('Action error: {0} [{1}] [{2}]').format(
+                exception.args[0], exception.args[1], exception.args[2]))
 
 
-def delete(request, number):
-    """Show confirmation to delete a snapshot."""
-    if request.method == 'POST':
-        actions.superuser_run('snapshot', ['delete', number])
-        messages.success(
-            request, _('Deleted snapshot #{number}.').format(number=number))
-        return redirect(reverse('snapshot:manage'))
-
-    output = actions.superuser_run('snapshot', ['list'])
-    snapshots = json.loads(output)
-    snapshot = next(s for s in snapshots if s['number'] == number)
-
-    return TemplateResponse(request, 'snapshot_delete.html', {
-        'title': _('Delete Snapshot'),
-        'snapshot': snapshot
-    })
-
-
-def delete_all(request):
-    """Show confirmation to delete all snapshots."""
-    if request.method == 'POST':
-        actions.superuser_run('snapshot', ['delete-all'])
-        messages.success(request, _('Deleted all snapshots.'))
-        return redirect(reverse('snapshot:manage'))
-
+def delete_selected(request):
     output = actions.superuser_run('snapshot', ['list'])
     snapshots = json.loads(output)
 
-    return TemplateResponse(request, 'snapshot_delete_all.html', {
-        'title': _('Delete Snapshots'),
-        'snapshots': snapshots[1:]
-    })
+    if request.method == 'POST':
+        if 'snapshots' in request.session:
+            to_delete = request.session['snapshots']
+            try:
+                if to_delete == len(snapshots):
+                    actions.superuser_run('snapshot', ['delete_all'])
+                    messages.success(request, _('Deleted all snapshots'))
+                else:
+                    for snapshot in to_delete:
+                        actions.superuser_run('snapshot', ['delete', snapshot])
+                    messages.success(request, _('Deleted selected snapshots'))
+            except ActionError as exception:
+                if 'Config is in use.' in exception.args[2]:
+                    messages.error(
+                        request,
+                        _('Snapshot is currently in use. '
+                          'Please try again later.'))
+                else:
+                    raise
+
+            return redirect(reverse('snapshot:manage'))
+
+    if 'snapshots' in request.session:
+        data = request.session['snapshots']
+        to_delete = list(filter(lambda x: x['number'] in data, snapshots))
+
+        return TemplateResponse(request, 'snapshot_delete_selected.html', {
+            'title': _('Delete Snapshots'),
+            'snapshots': to_delete
+        })
 
 
 def rollback(request, number):
