@@ -28,6 +28,8 @@ from django.utils.translation import ugettext as _, ugettext_lazy
 
 from .forms import CreateUserForm, UserChangePasswordForm, UserUpdateForm, \
     FirstBootForm
+from . import get_last_admin_user
+
 from plinth import actions
 from plinth.errors import ActionError
 from plinth.modules import first_boot
@@ -65,6 +67,10 @@ class UserCreate(ContextMixin, SuccessMessageMixin, CreateView):
         kwargs['request'] = self.request
         return kwargs
 
+    def get_success_url(self):
+        """Return the URL to redirect to in case of successful updation."""
+        return reverse('users:index')
+
 
 class UserList(ContextMixin, django.views.generic.ListView):
     """View to list users."""
@@ -72,6 +78,13 @@ class UserList(ContextMixin, django.views.generic.ListView):
     template_name = 'users_list.html'
     title = ugettext_lazy('Users')
 
+    def get_context_data(self, *args, **kwargs):
+        context = super(UserList, self).get_context_data(*args, **kwargs)
+        last_admin_user = get_last_admin_user()
+        if last_admin_user is not None:
+            context['last_admin_user'] = last_admin_user
+        return context
+
 
 class UserUpdate(ContextMixin, SuccessMessageMixin, UpdateView):
     """View to update a user's details."""
@@ -85,7 +98,7 @@ class UserUpdate(ContextMixin, SuccessMessageMixin, UpdateView):
     def dispatch(self, request, *args, **kwargs):
         """Handle a request and return a HTTP response."""
         if self.request.user.get_username() != self.kwargs['slug'] \
-           and not is_user_admin(self.request):
+                and not is_user_admin(self.request):
             raise PermissionDenied
 
         return super().dispatch(request, *args, **kwargs)
@@ -114,6 +127,13 @@ class UserUpdate(ContextMixin, SuccessMessageMixin, UpdateView):
         """Return the URL to redirect to in case of successful updation."""
         return reverse('users:edit', kwargs={'slug': self.object.username})
 
+    def get_context_data(self, **kwargs):
+        """Use self.title and the module-level subsubmenu"""
+        context = super(UserUpdate, self).get_context_data(**kwargs)
+        if not is_user_admin(self.request):
+            del context['subsubmenu']
+        return context
+
 
 class UserDelete(ContextMixin, DeleteView):
     """Handle deleting users, showing a confirmation dialog first.
@@ -157,7 +177,7 @@ class UserChangePassword(ContextMixin, SuccessMessageMixin, FormView):
     def dispatch(self, request, *args, **kwargs):
         """Handle a request and return a HTTP response."""
         if self.request.user.get_username() != self.kwargs['slug'] \
-           and not is_user_admin(self.request):
+                and not is_user_admin(self.request):
             raise PermissionDenied
 
         return super().dispatch(request, *args, **kwargs)
@@ -185,6 +205,13 @@ class UserChangePassword(ContextMixin, SuccessMessageMixin, FormView):
         update_session_auth_hash(self.request, form.user)
         return super(UserChangePassword, self).form_valid(form)
 
+    def get_context_data(self, **kwargs):
+        """Remove subsubmenu for non-admin users."""
+        context = super(UserChangePassword, self).get_context_data(**kwargs)
+        if not is_user_admin(self.request):
+            del context['subsubmenu']
+        return context
+
 
 class FirstBootView(django.views.generic.CreateView):
     """Create user account and log the user in."""
